=================================
Scheme Editor (:mod:`schemeedit`)
=================================

.. automodule:: orangecanvas.document.schemeedit


.. autoclass:: SchemeEditWidget
   :members:
   :exclude-members:
      undoAvailable,
      redoAvailable,
      modificationChanged,
      undoCommandAdded,
      selectionChanged,
      titleChanged,
      pathChanged,
      onNewLink
   :member-order: bysource
   :show-inheritance:

   .. autoattribute:: undoAvailable(bool)

   .. autoattribute:: redoAvailable(bool)

   .. autoattribute:: modificationChanged(bool)

   .. autoattribute:: undoCommandAdded()

   .. autoattribute:: selectionChanged()

   .. autoattribute:: titleChanged()

   .. autoattribute:: pathChanged()
